@@ -26,11 +26,6 @@
 #include <libglom/connectionpool.h>
 #include <libglom/data_structure/glomconversions.h>
 
-#include <libglom/data_structure/field.h>
-#include <glibmm/ustring.h>
-
-//#include "glom/appwindow.h"
-
 namespace Glom
 {
 
