@@ -22,6 +22,8 @@
 #include "box_db_table_relationships.h"
 #include <glom/appwindow.h>
 #include <libglom/db_utils.h>
+#include <libglom/utils.h>
+#include <libglom/string_utils.h>
 #include <algorithm>
 #include <glibmm/i18n.h>
 
@@ -91,7 +93,7 @@ bool Box_DB_Table_Relationships::fill_from_database()
     m_AddDel.set_column_choices(m_colFromField, util_vecStrings_from_Fields(
       DbUtils::get_fields_for_table(document, m_table_name)));
 
-    type_vec_strings vecTableNames = document->get_table_names(false /* ignore_system_tables */);
+    const auto vecTableNames = document->get_table_names(false /* ignore_system_tables */);
     type_vec_strings vecTableNames_ustring(vecTableNames.begin(), vecTableNames.end());
     m_AddDel.set_column_choices(m_colToTable, vecTableNames_ustring);
 
@@ -244,7 +246,7 @@ void Box_DB_Table_Relationships::on_adddel_user_activated(const Gtk::TreeModel::
         auto connection = sharedconnection->get_gda_connection();
 
         auto document = get_document();
-        type_vec_strings vecFields = util_vecStrings_from_Fields(DbUtils::get_fields_for_table(document, table_name));
+        const auto vecFields = util_vecStrings_from_Fields(DbUtils::get_fields_for_table(document, table_name));
 
         //This would cause a lot of tedious re-filling:
         //m_AddDel.set_column_choices(m_colToField, vecFields);
